@@ -1,5 +1,5 @@
 # Copyright (c) 2014 Sean Vig
-# Copyright (c) 2014 zordsdavini
+# Copyright (c) 2014, 2019 zordsdavini
 # Copyright (c) 2014 Alexandr Kriptonov
 # Copyright (c) 2014 Tycho Andersen
 #
@@ -28,14 +28,14 @@ import re
 
 
 class GmailChecker(base.ThreadedPollText):
-    """A simple gmail checker"""
+    """A simple gmail checker. If 'status_only_unseen' is True - set 'fmt' for one argument, ex. 'unseen: {0}'"""
     orientations = base.ORIENTATION_HORIZONTAL
     defaults = [
         ("update_interval", 30, "Update time in seconds."),
         ("username", None, "username"),
         ("password", None, "password"),
         ("email_path", "INBOX", "email_path"),
-        ("fmt", "inbox[%s],unseen[%s]", "fmt"),
+        ("fmt", "inbox[{0}],unseen[{1}]", "fmt"),
         ("status_only_unseen", False, "Only show unseen messages"),
     ]
 
@@ -50,12 +50,12 @@ class GmailChecker(base.ThreadedPollText):
                                              '(MESSAGES UNSEEN)')
         if answer == "OK":
             dec = raw_data[0].decode()
-            messages = int(re.search('MESSAGES\s+(\d+)', dec).group(1))
-            unseen = int(re.search('UNSEEN\s+(\d+)', dec).group(1))
+            messages = int(re.search(r'MESSAGES\s+(\d+)', dec).group(1))
+            unseen = int(re.search(r'UNSEEN\s+(\d+)', dec).group(1))
             if(self.status_only_unseen):
-                return self.fmt % unseen
+                return self.fmt.format(unseen)
             else:
-                return self.fmt % (messages, unseen)
+                return self.fmt.format(messages, unseen)
         else:
             logger.exception(
                 'GmailChecker UNKNOWN error, answer: %s, raw_data: %s',
